aboutsummaryrefslogtreecommitdiff
path: root/ext/js/comm/api.js
diff options
context:
space:
mode:
Diffstat (limited to 'ext/js/comm/api.js')
-rw-r--r--ext/js/comm/api.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/ext/js/comm/api.js b/ext/js/comm/api.js
index 40b8e252..f07702da 100644
--- a/ext/js/comm/api.js
+++ b/ext/js/comm/api.js
@@ -253,13 +253,13 @@ export class API {
}
/**
* @param {import('api').ApiParam<'log', 'error'>} error
* @param {import('api').ApiParam<'log', 'level'>} level
* @param {import('api').ApiParam<'log', 'context'>} context
* @returns {Promise<import('api').ApiReturn<'log'>>}
*/
- log(error, level, context) {
- return this._invoke('log', {error, level, context});
+ logGenericErrorBackend(error, level, context) {
+ return this._invoke('logGenericErrorBackend', {error, level, context});
}
/**
@@ -253,13 +253,13 @@ export class API {
}
/**
- * @param {import('api').ApiParam<'log', 'error'>} error
- * @param {import('api').ApiParam<'log', 'level'>} level
- * @param {import('api').ApiParam<'log', 'context'>} context
- * @returns {Promise<import('api').ApiReturn<'log'>>}
+ * @param {import('api').ApiParam<'logGenericErrorBackend', 'error'>} error
+ * @param {import('api').ApiParam<'logGenericErrorBackend', 'level'>} level
+ * @param {import('api').ApiParam<'logGenericErrorBackend', 'context'>} context
+ * @returns {Promise<import('api').ApiReturn<'logGenericErrorBackend'>>}
*/